/***********************************************************************/
/*                                                                     */
/*  FILE        :Main.c or Main.cpp                                    */
/*  DATE        :Tue, Oct 31, 2006                                     */
/*  DESCRIPTION :Main Program                                          */
/*  CPU TYPE    :                                                      */
/*                                                                     */
/*  NOTE:THIS IS A TYPICAL EXAMPLE.                                    */
/*                                                                     */
/***********************************************************************/

/*******************************************************************************
Includes <System Includes> , "Project Includes"
*******************************************************************************/
//#include "typedefine.h"
#include "R_PG_ComplementaryPWM_RX210.h"

/*******************************************************************************
Macro definitions
*******************************************************************************/
#define NUM_WAVEFORM       (4)  /* setting the number of type of PWM waveform */
#define CYCLE_TIMES        (10)     /* times of cycle when change next waveform */

/*******************************************************************************
* Constant Definition
*******************************************************************************/
const uint16_t duty_ratio[NUM_WAVEFORM] = 
{
    1000, 2500, 0, 4000
}; /* setting duty ratio */

/*******************************************************************************
* Private global variables and functions
*******************************************************************************/
volatile uint8_t int_count    = 0;     /* store the number of interrupted by MTU3 */
volatile uint8_t current_wave = 0;  /* store the current wave (range:0 ~ (NUM_WAVEFORM-1 )) */

/*******************************************************************************
* Function Name: main
* Description  : Main program
* Arguments    : none
* Return Value : none
*******************************************************************************/
void main(void)
{
    
    /* MTU3,4 start counting at the same time */
    R_PG_Timer_SynchronouslyStartCount_MTU_U0(
        0, /* ch0 */
        0, /* ch1 */
        0, /* ch2 */
        1, /* ch3 */
        1  /* ch4 */
    );
    
    
    while(1)
    {
        /* output PWM wave changing times. */
        if ( CYCLE_TIMES <= int_count )
        {
            /* begin: change next wave */
            if ( (NUM_WAVEFORM-1) > current_wave )
            {
                current_wave++;
            }
            else
            {
                current_wave = 0;
            }
        
            /* begin: update duty ratio */
            R_PG_Timer_SetTGR_D_MTU_U0_C3(duty_ratio[current_wave]);
            R_PG_Timer_SetTGR_C_MTU_U0_C4(duty_ratio[current_wave]);
            R_PG_Timer_SetTGR_D_MTU_U0_C4(duty_ratio[current_wave]);
            /* end: update duty ratio */
            
            int_count = 0; /* initialize counter */
            
            /* end: change next wave */
        }
        else
        {
            /* do nothing */
        }
    }
    
}

/*******************************************************************************
* Function Name: Mtu3IntFunc_A
* Description  : interrupt function for MTU2.TCNT3 compare macth TGRA
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Mtu3IntFunc_A(void){
    int_count++;
}

/******************************************************************************
Option-Setting Memory
******************************************************************************/
#pragma address OFS1_REG = 0xFFFFFF88   /* OFS1 register */
const unsigned long OFS1_REG = 0xFFFFFFFF;

#pragma address OFS0_REG = 0xFFFFFF8C   /* OFS0 register */
const unsigned long OFS0_REG = 0xFFFFFFFF;